@@ -12,8 +12,8 @@ flag_definitions = {
     'DFS':		1<<4,
     'PTP-ONLY':		1<<5,
     'PTMP-ONLY':	1<<6,
-    'PASSIVE-SCAN':	1<<7,
-    'NO-IBSS':		1<<8,
+    'NO-IR':	        1<<7,
+    # hole at bit 8
     # hole at bit 9. FIXME: Where is NO-HT40 defined?
     'NO-HT40':		1<<10,
 }
@@ -205,13 +205,10 @@ class DBParser(object):
 
     def _parse_power_def(self, pname, line, dupwarn=True):
         try:
-            (max_ant_gain,
-             max_eirp) = line.split(',')
-            if max_ant_gain == 'N/A':
-                max_ant_gain = '0'
+            max_eirp = line
             if max_eirp == 'N/A':
                 max_eirp = '0'
-            max_ant_gain = float(max_ant_gain)
+            max_ant_gain = float(0)
             def conv_pwr(pwr):
                 if pwr.endswith('mW'):
                     pwr = float(pwr[:-2])
